@@ -5,6 +5,7 @@ OC.L10N.register(
     "All contacts" : "Alle kontakte",
     "Contacts" : "Kontakte",
     "A contacts app for Nextcloud" : "’n Kontakte-toep vir Nextcloud",
+    "General" : "Algemeen",
     "Rename" : "Hernoem",
     "Delete" : "Skrap",
     "Copied" : "Gekopieer",
@@ -21,7 +22,9 @@ OC.L10N.register(
     "Last modified" : "Laas gewysig",
     "Save" : "Bewaar",
     "Close" : "Sluit",
+    "Folder name" : "Vouernaam",
     "Edit" : "Wysig",
+    "Create" : "Skep",
     "Invalid image" : "Ongeldige beeld",
     "Name" : "Naam",
     "Title" : "Titel",
