@@ -6,17 +6,16 @@ OC.L10N.register(
     "Delete" : "﻿ಅಳಿಸಿ",
     "Download" : "ಪ್ರತಿಯನ್ನು ಸ್ಥಳೀಯವಾಗಿ ಉಳಿಸಿಕೊಳ್ಳಿ",
     "can edit" : "﻿ಸಂಪಾದಿಸಬಹುದು",
-    "Add" : "﻿ಸೇರಿಸಿ",
-    "Password protection" : "Password protection",
-    "Save" : "﻿ಉಳಿಸಿ",
-    "Settings" : "Settings",
     "Cancel" : "﻿ರದ್ದು",
+    "Add" : "﻿ಸೇರಿಸಿ",
+    "Save" : "﻿ಉಳಿಸಿ",
+    "Close" : "ಮುಚ್ಚು",
+    "Create" : "ಸೃಷ್ಟಿಸಿ",
     "Invalid image" : "ಅಸಾಮರ್ಥ್ಯ ಚಿತ್ರ",
     "Name" : "﻿ಹೆಸರು",
     "Title" : "ಶೀರ್ಷಿಕೆ",
     "Pending" : "﻿ಬಾಕಿ ಇದೆ",
     "None" : "﻿ಯಾವುದೂ ಇಲ್ಲ",
-    "Close" : "ಮುಚ್ಚು",
     "Import" : "ಆಮದು",
     "User" : "User",
     "Group" : "﻿ಗುಂಪು",
