@@ -7,18 +7,20 @@ OC.L10N.register(
     "Delete" : "Ta bort",
     "Download" : "Last ned",
     "can edit" : "kan endra",
+    "Cancel" : "Avbryt",
     "Add" : "Legg til",
     "First name" : "Fornamn",
     "Last name" : "Etternamn",
     "Last modified" : "Siste endra",
     "Save" : "Lagre",
-    "Cancel" : "Avbryt",
+    "Close" : "Lukk",
+    "Folder name" : "Mappe namn",
+    "Create" : "Lag",
     "Invalid image" : "Ugyldig bilete",
     "Name" : "Namn",
     "Title" : "Tittel",
     "Pending" : "Under vegs",
     "None" : "Ingen",
-    "Close" : "Lukk",
     "Import" : "Importer",
     "Not grouped" : "Ikkje gruppert",
     "User" : "Bruker",
