@@ -25,9 +25,12 @@ OC.L10N.register(
     "Manage team" : "管理团队",
     "Leave team" : "离开团队",
     "Delete team" : "删除团队",
+    "Setting saved" : "设置已保存",
+    "Failed to save setting" : "无法保存设置",
     "Contacts settings" : "联系人设置",
-    "General" : "普通",
+    "General" : "常规",
     "Update avatars from social media" : "从社交媒体更新头像",
+    "Refreshed once per week" : "每周刷新一次",
     "Address books" : "地址簿",
     "Rename" : "重命名",
     "Export" : "导出",
@@ -79,6 +82,7 @@ OC.L10N.register(
     "Import from files" : "从文件导入",
     "Importing is disabled because there are no address books available" : "导入已禁用，因为没有可用的通讯录",
     "An error occurred, unable to create the address book" : "发生错误，无法创建通讯录",
+    "New address book" : "新通讯录",
     "Add new address book" : "添加新通讯录",
     "Cancel" : "取消",
     "Add" : "添加",
@@ -88,6 +92,7 @@ OC.L10N.register(
     "Phonetic last name" : "语音姓氏",
     "Display name" : "显示名称",
     "Last modified" : "上一次更改",
+    "Sort contacts by" : "排序联系人方式",
     "Manages" : "管理",
     "Oversees" : "监督",
     "An error happened during the config change" : "更改配置时发生一个错误",
@@ -100,13 +105,32 @@ OC.L10N.register(
     "Close" : "关闭",
     "There is no description for this team" : "此团队没有描述",
     "Enter a description for the team" : "输入团队的描述",
+    "Team folder" : "团队文件夹",
+    "New Team folder" : "新团队文件夹",
+    "Folder name" : "文件夹名称",
+    "Talk conversation" : "Talk 对话",
+    "New Talk conversation" : "新 Talk 对话",
     "Conversation name" : "对话名称",
+    "Collective" : "集体",
+    "Calendar" : "日历",
+    "New calendar" : "新日历",
+    "Calendar name" : "日历名称",
+    "Deck board" : "Deck 面板",
+    "New Deck board" : "新 Deck 面板",
+    "Board name" : "面板名称",
+    "Deck app is not installed. Please install it to create team boards." : "未安装 Deck 应用。请安装它以创建团队面板。",
+    "Unknown resource type" : "未知资源类型",
+    "Team calendar \"{resourceName}\" created and shared with team" : "团队日历“{resourceName}”已创建并与团队共享",
+    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType}“{resourceName}”已创建并与团队共享",
+    "A calendar named \"{name}\" already exists. Please choose a different name." : "名为“{name}”的日历已存在。请选择其他名称。",
+    "Failed to create {resourceType}: {error}" : "无法创建 {resourceType}：{error}",
     "An error happened while saving {fields}" : "保存 {fields} 时出错",
     "Team name" : "团队名称",
     "Team owner" : "团队所有者",
     "Edit" : "编辑",
     "Request to join" : "请求加入",
     "Create" : "创建",
+    "Show in Calendar" : "在日历中显示",
     "Your request to join this team is pending approval" : "您加入此团队的请求正在等待批准",
     "You are not a member of {circle}" : "您并非 {circle} 的成员",
     "Members" : "成员",
@@ -157,6 +181,7 @@ OC.L10N.register(
     "Calendar events with you" : "与您分享的日历事件",
     "Deck cards with you" : "与您分享的卡片",
     "No shared items with this contact" : "与该联系人无共享项目",
+    "Move" : "Move",
     "Confirm merging contacts" : "确认合并联系人",
     "The selected contacts have conflicting information. Choose which information to keep" : "所选联系人的信息存在冲突。请选择要保留的信息",
     "Contacts can be merged" : "联系人可以合并",
