@@ -181,6 +181,15 @@ OC.L10N.register(
     "Calendar events with you" : "與您分享的日曆活動",
     "Deck cards with you" : "與您分享的 Deck 卡片",
     "No shared items with this contact" : "沒有與該聯絡人分享的項目",
+    "Add contacts to groups" : "添加增聯絡人到群組",
+    "Move contacts to addressbook" : "將聯絡人移至地址簿",
+    "Select groups" : "選擇群組",
+    "Select addressbook" : "選擇地址簿",
+    "Selected contacts" : "已選的聯絡人",
+    "Please note that only {count} of the {total} contacts can be added to a group" : "請注意：在 {total} 個聯絡人中，只能將其中 {count} 個加入群組",
+    "Please note that only {count} of the {total} contacts can be moved" : "請注意：在 {total} 個聯絡人中，只能將其中 {count} 個移動",
+    "Move" : "移動",
+    "from {addressbook}" : "從 {addressbook}",
     "Confirm merging contacts" : "確認合併聯絡人",
     "The selected contacts have conflicting information. Choose which information to keep" : "所選的聯絡人有衝突的資訊。請選擇要保留的資訊",
     "Contacts can be merged" : "聯絡人可以合併",
@@ -188,9 +197,14 @@ OC.L10N.register(
     "Select groups to add the merged contact to" : "選擇要將合併的聯絡人添加到的群組",
     "Merge contacts" : "合併聯絡人",
     "_Delete {number} contact_::_Delete {number} contacts_" : ["刪除 {number} 個聯絡人"],
-    "Please select at least one editable contact to delete" : "請選取至少一個可編輯的聯絡人來刪除",
+    "Please select at least one editable contact to delete" : "請至少選擇一個可編輯的聯絡人以刪除",
     "Please select two editable contacts to merge" : "請選擇兩個可編輯的聯絡人進行合併",
+    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["添加 {number} 個聯絡人至群組"],
+    "Please select at least one editable contact to add to a group" : "請至少選擇一個可編輯的聯絡人以加入群組",
+    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["將 {number} 個聯絡人移至地址簿"],
+    "Please select at least one editable contact to move to an addressbook" : "請至少選擇一個可編輯的聯絡人以移至地址簿",
     "Are you sure you want to proceed?" : "您想要繼續嗎？",
+    "Add contacts to group" : "將聯絡人加入群組",
     "Search contacts …" : "搜尋聯絡人 …",
     "Unselect {number}" : "取消選取 {number}",
     "Add to {group}" : "新增至 {group]",
