@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -27,12 +28,13 @@ class MastodonProvider implements ISocialProvider {
 	 *
 	 * @return bool
 	 */
+	#[\Override]
 	public function supportsContact(array $contact):bool {
 		if (!array_key_exists('X-SOCIALPROFILE', $contact)) {
 			return false;
 		}
 		$profiles = $this->getProfileIds($contact);
-		return isset($profiles) && count($profiles) > 0;
+		return count($profiles) > 0;
 	}
 
 	/**
@@ -42,6 +44,7 @@ class MastodonProvider implements ISocialProvider {
 	 *
 	 * @return array
 	 */
+	#[\Override]
 	public function getImageUrls(array $contact):array {
 		$profileIds = $this->getProfileIds($contact);
 		$urls = [];
